=================
steampipe-alchemy
=================


.. image:: https://img.shields.io/pypi/v/steampipe_alchemy.svg
        :target: https://pypi.python.org/pypi/steampipe_alchemy

.. image:: https://img.shields.io/travis/RyanJarv/steampipe_alchemy.svg
        :target: https://travis-ci.com/RyanJarv/steampipe_alchemy

.. image:: https://readthedocs.org/projects/steampipe-alchemy/badge/?version=latest
        :target: https://steampipe-alchemy.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




A simple `SQLAlchemy <https://www.sqlalchemy.org/>`_ wrapper around `Steampipe <https://steampipe.io/>`_.

Currently this is a work in progress. Models exist for the AWS plugin, others will be added in the future.

* Free software: BSD license
* Documentation: [WIP] https://steampipe-alchemy.readthedocs.io.


Features
--------

